pub struct ChangePasswordTemplate {
pub error: Option<String>,
pub username: String,
}Fields
error: Option<String>username: StringTrait Implementations
Sourceimpl Display for ChangePasswordTemplate
impl Display for ChangePasswordTemplate
Sourceimpl IntoResponse for ChangePasswordTemplate
impl IntoResponse for ChangePasswordTemplate
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response
Create a response.
Sourceimpl Template for ChangePasswordTemplate
impl Template for ChangePasswordTemplate
Sourceconst SIZE_HINT: usize = 1616
const SIZE_HINT: usize = 1616
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template
Sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt bufferAuto Trait Implementations
impl Freeze for ChangePasswordTemplate
impl RefUnwindSafe for ChangePasswordTemplate
impl Send for ChangePasswordTemplate
impl Sync for ChangePasswordTemplate
impl Unpin for ChangePasswordTemplate
impl UnsafeUnpin for ChangePasswordTemplate
impl UnwindSafe for ChangePasswordTemplate