pub struct InviteTemplate {
pub username: String,
pub error: Option<String>,
}Fields
username: Stringerror: Option<String>Trait Implementations
Sourceimpl Display for InviteTemplate
impl Display for InviteTemplate
Sourceimpl IntoResponse for InviteTemplate
impl IntoResponse for InviteTemplate
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response
Create a response.
Sourceimpl Template for InviteTemplate
impl Template for InviteTemplate
Sourceconst SIZE_HINT: usize = 1183
const SIZE_HINT: usize = 1183
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template
Sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt bufferAuto Trait Implementations
impl Freeze for InviteTemplate
impl RefUnwindSafe for InviteTemplate
impl Send for InviteTemplate
impl Sync for InviteTemplate
impl Unpin for InviteTemplate
impl UnsafeUnpin for InviteTemplate
impl UnwindSafe for InviteTemplate