pub struct LoginTemplate {
pub error: Option<String>,
}Fields
error: Option<String>Trait Implementations
Sourceimpl Display for LoginTemplate
impl Display for LoginTemplate
Sourceimpl IntoResponse for LoginTemplate
impl IntoResponse for LoginTemplate
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response
Create a response.
Sourceimpl Template for LoginTemplate
impl Template for LoginTemplate
Sourceconst SIZE_HINT: usize = 1103
const SIZE_HINT: usize = 1103
Provides a rough estimate of the expanded length of the rendered template. Larger
values result in higher memory usage but fewer reallocations. Smaller values result in the
opposite. This value only affects
render. It does not take effect when calling
render_into, write_into, the fmt::Display implementation, or the blanket
ToString::to_string implementation.Sourceconst MIME_TYPE: &'static str = "text/html; charset=utf-8"
const MIME_TYPE: &'static str = "text/html; charset=utf-8"
The MIME type (Content-Type) of the data that gets rendered by this Template
Sourcefn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
fn render_into(&self, writer: &mut (impl Write + ?Sized)) -> Result<()>
Renders the template to the given
writer fmt bufferAuto Trait Implementations
impl Freeze for LoginTemplate
impl RefUnwindSafe for LoginTemplate
impl Send for LoginTemplate
impl Sync for LoginTemplate
impl Unpin for LoginTemplate
impl UnsafeUnpin for LoginTemplate
impl UnwindSafe for LoginTemplate